@@ -20,8 +20,11 @@
 using namespace std;
 
 void GLWidget::mousePressEvent(QMouseEvent *event) {
-	mx = event->globalX();
-	my = event->globalY();	
+	showQuitButton = !showQuitButton;
+	if(showQuitButton) {
+		quitButton->hide();
+	}
+	else quitButton->show();	
 }
 
 void GLWidget::mouseReleaseEvent(QMouseEvent *event) {
@@ -42,7 +45,6 @@ void GLWidget::getOrientation() {
 		re.indexIn(line);
 		int x = re.cap(1).toInt();
 		int y = re.cap(2).toInt();
-		int z = re.cap(3).toInt();
 		xax = x ; //atan2((float) x, (float) -y);
 		yax = y ;//atan2((float) y, (float) -z);
 		//pitch = (pitch * 180/M_PI)*-1;
@@ -62,9 +64,8 @@ void GLWidget::keyPressEvent(QKeyEvent *event) {
 			keyIndex = 15;
 		}
 		if(lopussa && (event->text() == "q")) {
-			releaseKeyboard();
-			emit onClose();
-			this->hide();
+			keskeytetty = false;
+			hideGame();
 		}
 	}
 }
@@ -82,15 +83,28 @@ void GLWidget::keyReleaseEvent(QKeyEvent *event) {
 GLWidget::GLWidget(QMainWindow *parent) : QGLWidget(parent) {
 	timer = new QTimer(this);
 	connect(timer, SIGNAL(timeout()), this, SLOT(paivita()));
-	timer->start(1);
+	timer->start(20);
 	QTimer *avoiding = new QTimer(this);
 	connect(avoiding, SIGNAL(timeout()), this, SLOT(avoidScreensaver()));
 	avoiding->start(30000);
 	bestlap = 999.999;
 	keyIndex = 0;
+	QHBoxLayout *layout = new QHBoxLayout(this);
+	quitButton = new QPushButton("Back to Menu", this);
+	layout->addWidget(quitButton);
+	this->setLayout(layout);
+	quitButton->hide();
+	showQuitButton = false;
+	
+	connect(quitButton, SIGNAL(clicked()), this, SLOT(hideGame()));	
+	
+	
 }
 
 void GLWidget::newGame() {
+	keskeytetty = true;	
+	showQuitButton = false;
+	quitButton->hide();
 	grabKeyboard();	
 	keyIndex = 0;
 	lopussa = true;
@@ -530,4 +544,8 @@ void GLWidget::Plane() {
 }
 	
 
+void GLWidget::hideGame() {
+	releaseKeyboard();
+	emit onClose();
+}
 
